MediaMetadataPlatform class abstract

The interface that implementations of media_metadata must implement.

Inheritance
  • Object
  • PlatformInterface
  • MediaMetadataPlatform
Implementers

Constructors

MediaMetadataPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readMetadata(String filePath, {bool createThumbnail = false}) Future<Metadata?>
Reads metadata from the file at filePath.
toString() String
A string representation of this object.
inherited
writeMetadata(String filePath, Metadata metadata) Future<bool>
Writes metadata to the file at filePath.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance MediaMetadataPlatform
The default instance of MediaMetadataPlatform to use.
getter/setter pair