readMetadata method
Reads metadata from the file at filePath.
When createThumbnail is true and the file is a video with no
embedded artwork, a thumbnail is generated from a video frame (see
MediaMetadata.read for details).
Returns a Metadata object, or null if the file cannot be read.
Implementation
Future<Metadata?> readMetadata(String filePath, {bool createThumbnail = false}) {
throw UnimplementedError('readMetadata() has not been implemented.');
}